import os

import click


@click.command()
@click.option("--format-code", "-f", is_flag=True, help="Auto format the code.")
@click.option("--inplace", "-i", is_flag=True, help="Make changes in place")
@click.option(
    "--exclude-path", "-e", default="", help="Exclude some path from processing"
)
@click.option("--lint", "-l", is_flag=True, help="Lint the code")
def worker(format_code, inplace, exclude_path, lint):
    click.echo(f"{os.getcwd()}")
    if format_code:
        click.echo(f"Formatting code... \nInplace -> {inplace}")
        run_commands(inplace, exclude_path)
    elif lint:
        click.echo("Running lint...")
        run_commands(inplace=False, exclude_path=exclude_path)


def run_commands(inplace, exclude_path=""):
    click.echo("Running auto-flake... ")
    os.system(
        f"autoflake -r {'--in-place' if inplace else ''}"
        f"{'--exclude ' + exclude_path if exclude_path else ''} "
        "--remove-unused-variables --remove-all-unused-imports  **/"
    )

    click.echo("Running isort...")
    os.system(
        "isort **/ --multi-line 3 --trailing-comma --line-width 88 "
        f"{'--skip ' + exclude_path if exclude_path else ''} "
        f"{'--check-only' if not inplace else ''}"
    )

    click.echo("Running black...")
    os.system(
        f"black **/ "
        f"{'--exclude ' + exclude_path if exclude_path else ''} "
        f"{'--check' if not inplace else ''}"
    )


if __name__ == "__main__":
    worker()



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

dependencies = [
    "click>7.1.2",
    "flake8>3.8.3",
    "black>19.10b0",
    "isort>5.0.9",
    "mypy>0.782",
    "autoflake>1.3.1",
]

setuptools.setup(
    name="lintit",
    version="0.0.1",
    author="Everton Tomalok",
    author_email="evertontomalok123@gmail.com",
    description="A cli linter",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/EvertonTomalok/lint-it",
    packages=setuptools.find_packages(exclude="tests"),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
    entry_points={
        'console_scripts': [
            'lintit = lint_it.linter:main',
        ],
    },
)